#! /usr/bin/perl

# makeXHTML.pl
#
# Author: Robert Hahn <rh-wsdf@tenletters.com>
#
# Date: December 8, 2003
#
# Copyright: (c) 2003 Permission granted to use this code provided that 
#            proper credit is given to the original author.
#
# I wrote this script as a one off designed to get me 80% of the way there in
# creating my first WSDF file.  Since my blog tool of choice is Blosxom, I have
# a very small set of assumptions to work with in generating my WSDF.
#
# This script is distributed 'as is', with no warranty, etc. 
#
# If you have a pile of statically rendered HTML pages sitting in directories
# that more or less correspond to the various sections in your site, this may 
# work for you.  This is how you use it:
#
# find . -name "*" -print | ./makeXHTML.pl > wsdf.html
#
# The find command, when used at the root of your pile of static HTML pages,
# returns a list of all files contained within.  The results are piped into 
# this script, which serves as the dataset that it works with. The output is
# redirected to wsdf.html, where you can add the trimmings to make it an XHTML
# file.
#
# The script will iterate through each file returned in the input list, 
# determine what kind of file it is, and if it's an html file, open it up and
# get the contents of the <title> tag.
#
# Then the script will print to STDOUT object tags properly
# formatted for WSDF and some default contents.
#
# This script is really rough around the edges; I'm sure you'll find some bugs,
# but as I've said before, it's provided to you as a way to get a leg up on
# building your first file.
#
# This script isn't intelligent enough to figure out what a section is, but the
# output is in sorted order, so it should be pretty trivial for you to add as
# many <div /> tags as are required to properly structure your file.

# set $root to be the base URI of your web site.
#   $root = "http://www.tenletters.com/rhahn/";

$root = "";

# a hash mapping file extensions to mimetypes

%mimetypes = ( html => "text/html",
				css => "text/css",
				rss => "application/xml",
				js  => "text/javascript",
				gif => "image/gif",
				jpg => "image/jpg"
		);

# grab the input
@data = (<>);

foreach $line (@data) {
		if ($line =~ /\.(html|css|rss|js|gif|jpg)/) {

				# set the filetype
				$filetype = $mimetypes{$1};

				# set a default title. if it's an HTML file, we'll be
				# overwriting this value.
				$title = "$filetype file";

				if ( $filetype =~ /text\/html/ ) {
					open HTML, $line;

					while (<HTML>) {
						# if the line contains a title tag... get it.
						if($_ =~ /(<title>.*?<\/title>)/i) {
							$description = $1;
							break;
						}
					}

					close HTML;

					$description =~ s/<\/?title>//g;
					chomp $description;
				}

				$uri = $line;
				$uri =~ s/^.\//$root/;
				chomp $uri;

				# This line generates the actual object tag.
				$setup = "            <object data=\"$uri\" type=\"$filetype\">\n                $description\n            </object>\n\n";

				# print it out.
				print $setup;
		}
}

